#ifndef HARDWARE_PROFILE_H
#define HARDWARE_PROFILE_H

    /*******************************************************************/
    /******** USB stack hardware selection options *********************/
    /*******************************************************************/
    //This section is the set of definitions required by the MCHPFSUSB
    //  framework.  These definitions tell the firmware what mode it is
    //  running in, and where it can find the results to some information
    //  that the stack needs.
    //These definitions are required by every application developed with
    //  this revision of the MCHPFSUSB framework.  Please review each
    //  option carefully and determine which options are desired/required
    //  for your application.

    //The PICDEM FS USB Demo Board platform supports the USE_SELF_POWER_SENSE_IO
    //and USE_USB_BUS_SENSE_IO features.  Uncomment the below line(s) if
    //it is desireable to use one or both of the features.
    //#define USE_SELF_POWER_SENSE_IO
    #define tris_self_power     TRISAbits.TRISA2    // Input
    #if defined(USE_SELF_POWER_SENSE_IO)
    #define self_power          PORTAbits.RA2
    #else
    #define self_power          1
    #endif

    //#define USE_USB_BUS_SENSE_IO
    #define tris_usb_bus_sense  TRISAbits.TRISA1    // Input
    #if defined(USE_USB_BUS_SENSE_IO)
    #define USB_BUS_SENSE       PORTAbits.RA1
    #else
    #define USB_BUS_SENSE       1
    #endif


    //Uncomment the following line to make the output HEX of this  
    //  project work with the MCHPUSB Bootloader    
    //#define PROGRAMMABLE_WITH_USB_MCHPUSB_BOOTLOADER
	
    //Uncomment the following line to make the output HEX of this 
    //  project work with the HID Bootloader
    #define PROGRAMMABLE_WITH_USB_HID_BOOTLOADER		

    /*******************************************************************/
    /*******************************************************************/
    /*******************************************************************/
    /******** Application specific definitions *************************/
    /*******************************************************************/
    /*******************************************************************/
    /*******************************************************************/

    /** Board definition ***********************************************/
    //These defintions will tell the main() function which board is
    //  currently selected.  This will allow the application to add
    //  the correct configuration bits as wells use the correct
    //  initialization functions for the board.  These defitions are only
    //  required in the stack provided demos.  They are not required in
    //  final application design.
    #define DEMO_BOARD PICDEM_FS_USB
    #define PICDEM_FS_USB
    #define CLOCK_FREQ 48000000


    /** LED ************************************************************/
    #define mInitAllLEDs()      LATB &= 0x7f; TRISB &= 0x7f;
    #define mLED_1              LATBbits.LATB7
    #define mGetLED_1()         mLED_1
    #define mLED_1_On()         mLED_1 = 1
    #define mLED_1_Off()        mLED_1 = 0
    #define mLED_1_Toggle()     mLED_1 = (!mLED_1)
    
    /** POT ************************************************************/
    //#define mInitPOT()          {TRISAbits.TRISA5=1; ADCON0=0x15; ADCON1=0; ADCON2=0x3C; ADCON2bits.ADFM = 1;}

    /** USB external transceiver interface (optional) ******************/
    #define tris_usb_vpo        TRISBbits.TRISB3    // Output
    #define tris_usb_vmo        TRISBbits.TRISB2    // Output
    #define tris_usb_rcv        TRISAbits.TRISA4    // Input
    #define tris_usb_vp         TRISCbits.TRISC5    // Input
    #define tris_usb_vm         TRISCbits.TRISC4    // Input
    #define tris_usb_oe         TRISCbits.TRISC1    // Output
    
    #define tris_usb_suspnd     TRISAbits.TRISA3    // Output

	/** STEPPERS *******************************************************/
	#define mInitAllSteppers()      LATB &= 0xf0; TRISB &= 0xf0; LATD &= 0x88; TRISD &= 0x88;
	#define mInitExtruder()      	LATE &= 0xfd; TRISE &= 0xfd;
    
    #define mStepperA_Dir		LATBbits.LATB2
    #define mStepperA_Step		LATBbits.LATB3
    #define mStepperB_Dir		LATBbits.LATB0
    #define mStepperB_Step		LATBbits.LATB1
    #define mStepperC_Dir		LATDbits.LATD5
    #define mStepperC_Step		LATDbits.LATD6
    #define mStepperD_Dir		LATDbits.LATD2
    #define mStepperD_Step		LATDbits.LATD4

	#define mExtruderHeater		LATEbits.LATE1

	/** ENDSTOPS *******************************************************/
	#define mInitAllEndStops()      TRISCbits.TRISC0=1; TRISCbits.TRISC2=1; TRISDbits.TRISD0=1;
    
    #define mEndStop_X			PORTCbits.RC0
    #define mEndStop_Y			PORTCbits.RC2
    #define mEndStop_Z			PORTDbits.RD0
    
    
    /** I/O pin definitions ********************************************/
    #define INPUT_PIN 1
    #define OUTPUT_PIN 0

#endif  //HARDWARE_PROFILE_H
